@@ -1,7 +1,7 @@
 #
 # Jinhom.R
 #
-#  $Revision: 1.9 $ $Date: 2014/10/24 00:22:30 $
+#  $Revision: 1.10 $ $Date: 2016/02/11 10:17:12 $
 #
 
 Ginhom <- function(X, lambda=NULL, lmin=NULL,
@@ -127,7 +127,8 @@ Ginhom <- function(X, lambda=NULL, lmin=NULL,
           v = as.double(vord),
           nr = as.integer(nr),
           rmax = as.double(rmax),
-          ans = as.double(numeric(npts * nr)))
+          ans = as.double(numeric(npts * nr)),
+          PACKAGE = "spatstat")
   ans <- matrix(z$ans, nrow=nr, ncol=npts)
   # revert to original ordering
   loccumprod <- matrix(,  nrow=nr, ncol=npts)
@@ -285,7 +286,7 @@ Finhom <- function(X, lambda=NULL, lmin=NULL,
   yord <- yy[oX]
   vord <- vv[oX]
   # determine pixel grid and compute distance to boundary
-  M <- do.call.matched("as.mask", append(list(w=W), list(...)))
+  M <- do.call.matched(as.mask, append(list(w=W), list(...)))
   bM <- bdist.pixels(M, style="matrix")
   bM <- as.vector(bM)
   # x, y coordinates of pixels are already sorted by increasing x
@@ -303,7 +304,8 @@ Finhom <- function(X, lambda=NULL, lmin=NULL,
          vdata = as.double(vord),
          nr = as.integer(nr),
          rmax = as.double(rmax),
-         ans = as.double(numeric(nM * nr)))
+         ans = as.double(numeric(nM * nr)),
+         PACKAGE = "spatstat")
   loccumprod <- matrix(z$ans, nrow=nr, ncol=nM)
   # border correction
   ok <- outer(r, bM, "<=")
