@@ -200,7 +200,8 @@ areadelta2 <- local({
                 yother = as.double(yy[K]),
                 radius = as.double(r),
                 epsilon = as.double(eps),
-                pixcount = as.integer(integer(1L)))
+                pixcount = as.integer(integer(1L)),
+                PACKAGE = "spatstat")
         result[i,j] <- result[j,i] <- z$pixcount
       }
       # normalise
@@ -345,7 +346,8 @@ areadelta2 <- local({
             yother = as.double(yy[K]),
             radius = as.double(r),
             epsilon = as.double(eps),
-            pixcount = as.integer(integer(1L)))
+            pixcount = as.integer(integer(1L)),
+            PACKAGE = "spatstat")
       result[i,j] <- z$pixcount
     }
     # normalise
