@@ -90,7 +90,8 @@ nndist.ppx <- function(X, ..., k=1) {
                m=as.integer(m),
                x= as.double(t(coo[o,])),
                nnd= as.double(nnd),
-               as.double(big))
+               as.double(big),
+               PACKAGE = "spatstat")
     nnd[o] <- Cout$nnd
   } else {
     # case kmaxcalc > 1
@@ -103,7 +104,8 @@ nndist.ppx <- function(X, ..., k=1) {
                kmax = as.integer(kmaxcalc),
                x    = as.double(t(coo[o,])),
                nnd  = as.double(nnd),
-               huge = as.double(big))
+               huge = as.double(big),
+               PACKAGE = "spatstat")
     nnd <- matrix(nnd, nrow=n, ncol=kmaxcalc)
     nnd[o, ] <- matrix(Cout$nnd, nrow=n, ncol=kmaxcalc, byrow=TRUE)
   }
@@ -177,7 +179,8 @@ nnwhich.ppx <- function(X, ..., k=1) {
                x = as.double(t(coo[o,])),
                nnd = as.double(numeric(n)),
                nnwhich = as.integer(nnw),
-               huge = as.double(big))
+               huge = as.double(big),
+               PACKAGE = "spatstat")
     witch <- Cout$nnwhich
     if(any(witch <= 0))
       stop("Internal error: non-positive index returned from C code")
@@ -196,7 +199,8 @@ nnwhich.ppx <- function(X, ..., k=1) {
                x = as.double(t(coo[o,])),
                nnd = as.double(numeric(n * kmaxcalc)),
                nnwhich = as.integer(nnw),
-               huge = as.double(big))
+               huge = as.double(big),
+               PACKAGE = "spatstat")
     witch <- Cout$nnwhich
     witch <- matrix(witch, nrow=n, ncol=kmaxcalc, byrow=TRUE)
     if(any(witch <= 0))
