@@ -3,7 +3,7 @@
 #
 #   nearest neighbour distances (nndist) and identifiers (nnwhich)
 #
-#   $Revision: 1.6 $ $Date: 2014/10/24 00:22:30 $
+#   $Revision: 1.7 $ $Date: 2016/02/11 10:17:12 $
 #
 
 nndist <- function(X, ...) {
@@ -25,7 +25,7 @@ nndist.ppp <- local({
     idX <- seq_len(npoints(X))
     Y <- split(X %mark% idX, f=by, un=FALSE)
     distY <- lapply(Y, nndistsub, XX=X, iX=idX, k=k)
-    result <- do.call("cbind", distY)
+    result <- do.call(cbind, distY)
     return(result)
   }
 
@@ -107,7 +107,8 @@ nndist.default <-
            z<- .C("nndistsort",
                   n= as.integer(n),
                   x= as.double(x[o]), y= as.double(y[o]), nnd= as.double(nnd),
-                  as.double(big))
+                  as.double(big),
+                  PACKAGE = "spatstat")
            nnd[o] <- z$nnd
          },
          stop(paste("Unrecognised method", sQuote(method)))
@@ -145,7 +146,8 @@ nndist.default <-
                     x    = as.double(x[o]),
                     y    = as.double(y[o]),
                     nnd  = as.double(nnd),
-                    huge = as.double(big))
+                    huge = as.double(big),
+                    PACKAGE = "spatstat")
              nnd <- matrix(nnd, nrow=n, ncol=kmaxcalc)
              nnd[o, ] <- matrix(z$nnd, nrow=n, ncol=kmaxcalc, byrow=TRUE)
            },
@@ -191,7 +193,7 @@ nnwhich.ppp <- local({
     idX <- seq_len(npoints(X))
     Y <- split(X %mark% idX, f=by, un=FALSE)
     whichY <- lapply(Y, nnwhichsub, XX=X, iX=idX, k=k)
-    result <- do.call("cbind", whichY)
+    result <- do.call(cbind, whichY)
     return(result)
   }
 
@@ -287,7 +289,8 @@ nnwhich.default <-
                     x = as.double(x[o]),
                     y = as.double(y[o]),
                     nnwhich = as.integer(nnw),
-                    huge = as.double(big))
+                    huge = as.double(big),
+                    PACKAGE = "spatstat")
              witch <- z$nnwhich # sic 
              if(any(witch <= 0))
                stop("Internal error: non-positive index returned from C code")
@@ -329,7 +332,8 @@ nnwhich.default <-
                     y = as.double(y[o]),
                     nnd = as.double(numeric(n * kmaxcalc)),
                     nnwhich = as.integer(nnw),
-                    huge = as.double(big))
+                    huge = as.double(big),
+                    PACKAGE = "spatstat")
              witch <- z$nnwhich # sic
              witch <- matrix(witch, nrow=n, ncol=kmaxcalc, byrow=TRUE)
              if(any(witch <= 0))
