@@ -9,12 +9,12 @@
 
 if(tracking) {
   /* saving transition history */
-#define MH_TRACKING TRUE
+#define MH_TRACKING YES
 #include "mhv4.h"
 #undef MH_TRACKING
 } else {
   /* not saving transition history */
-#define MH_TRACKING FALSE
+#define MH_TRACKING NO
 #include "mhv4.h"
 #undef MH_TRACKING
 } 
